@@ -1,37 +1,7 @@
-///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2004, Industrial Light & Magic, a division of Lucas
-// Digital Ltd. LLC
-// 
-// All rights reserved.
-// 
-// Redistribution and use in source and binary forms, with or without
-// modification, are permitted provided that the following conditions are
-// met:
-// *       Redistributions of source code must retain the above copyright
-// notice, this list of conditions and the following disclaimer.
-// *       Redistributions in binary form must reproduce the above
-// copyright notice, this list of conditions and the following disclaimer
-// in the documentation and/or other materials provided with the
-// distribution.
-// *       Neither the name of Industrial Light & Magic nor the names of
-// its contributors may be used to endorse or promote products derived
-// from this software without specific prior written permission. 
-// 
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+// SPDX-License-Identifier: BSD-3-Clause
+// Copyright (c) Contributors to the OpenEXR Project.
 //
-///////////////////////////////////////////////////////////////////////////
-
 
 #ifndef INCLUDED_IMF_TILED_INPUT_FILE_H
 #define INCLUDED_IMF_TILED_INPUT_FILE_H
@@ -42,22 +12,24 @@
 //
 //-----------------------------------------------------------------------------
 
-#include <ImfHeader.h>
-#include <ImfFrameBuffer.h>
-#include "ImathBox.h"
-#include <ImfTileDescription.h>
-#include <ImfThreading.h>
+#include "ImfForward.h"
 
-namespace Imf {
+#include "ImfThreading.h"
+#include "ImfGenericInputFile.h"
+
+#include "ImfTileDescription.h"
+#include <ImathBox.h>
+
+OPENEXR_IMF_INTERNAL_NAMESPACE_HEADER_ENTER
 
 
-class TiledInputFile
+class IMF_EXPORT_TYPE TiledInputFile : public GenericInputFile
 {
   public:
 
     //--------------------------------------------------------------------
     // A constructor that opens the file with the specified name, and
-    // reads the file header.  The constructor throws an Iex::ArgExc
+    // reads the file header.  The constructor throws an IEX_NAMESPACE::ArgExc
     // exception if the file is not tiled.
     // The numThreads parameter specifies how many worker threads this
     // file will try to keep busy when decompressing individual tiles.
@@ -65,6 +37,7 @@ class TiledInputFile
     // automatically closes the corresponding files.
     //--------------------------------------------------------------------
 
+    IMF_EXPORT
     TiledInputFile (const char fileName[],
                     int numThreads = globalThreadCount ());
 
@@ -77,20 +50,28 @@ class TiledInputFile
     // files.
     // ----------------------------------------------------------
 
-    TiledInputFile (IStream &is, int numThreads = globalThreadCount ());
+    IMF_EXPORT
+    TiledInputFile (OPENEXR_IMF_INTERNAL_NAMESPACE::IStream &is, int numThreads = globalThreadCount ());
 
 
     //-----------
     // Destructor
     //-----------
 
+    IMF_EXPORT
     virtual ~TiledInputFile ();
 
+    TiledInputFile (const TiledInputFile& other) = delete;
+    TiledInputFile& operator = (const TiledInputFile& other) = delete;
+    TiledInputFile (TiledInputFile&& other) = delete;
+    TiledInputFile& operator = (TiledInputFile&& other) = delete;
+
 
     //------------------------
     // Access to the file name
     //------------------------
 
+    IMF_EXPORT
     const char *	fileName () const;
 
 
@@ -98,6 +79,7 @@ class TiledInputFile
     // Access to the file header
     //--------------------------
 
+    IMF_EXPORT
     const Header &	header () const;
 
 
@@ -105,6 +87,7 @@ class TiledInputFile
     // Access to the file format version
     //----------------------------------
 
+    IMF_EXPORT
     int			version () const;
 
 
@@ -119,6 +102,7 @@ class TiledInputFile
     // to readTile().
     //-----------------------------------------------------------
 
+    IMF_EXPORT
     void		setFrameBuffer (const FrameBuffer &frameBuffer);
 
 
@@ -126,6 +110,7 @@ class TiledInputFile
     // Access to the current frame buffer
     //-----------------------------------
 
+    IMF_EXPORT
     const FrameBuffer &	frameBuffer () const;
 
 
@@ -139,6 +124,7 @@ class TiledInputFile
     // prematurely.)
     //------------------------------------------------------------
 
+    IMF_EXPORT
     bool		isComplete () const;
 
 
@@ -152,9 +138,13 @@ class TiledInputFile
     // fields of the file header's TileDescriptionAttribute.
     //---------------------------------------------------------
 
+    IMF_EXPORT
     unsigned int	tileXSize () const;
+    IMF_EXPORT
     unsigned int	tileYSize () const;
+    IMF_EXPORT
     LevelMode		levelMode () const;
+    IMF_EXPORT
     LevelRoundingMode	levelRoundingMode () const;
 
 
@@ -194,16 +184,20 @@ class TiledInputFile
     //      return value is the same as for numXLevels()
     //
     //	if levelMode() == RIPMAP_LEVELS:
-    //      an Iex::LogicExc exception is thrown
+    //      an IEX_NAMESPACE::LogicExc exception is thrown
     //
     // isValidLevel(lx, ly) returns true if the file contains 
     // a level with level number (lx, ly), false if not.
     //
     //--------------------------------------------------------------------
 
+    IMF_EXPORT
     int			numLevels () const;
+    IMF_EXPORT
     int			numXLevels () const;
+    IMF_EXPORT
     int			numYLevels () const;
+    IMF_EXPORT
     bool		isValidLevel (int lx, int ly) const;
 
 
@@ -225,7 +219,9 @@ class TiledInputFile
     //
     //----------------------------------------------------------
 
+    IMF_EXPORT
     int			levelWidth  (int lx) const;
+    IMF_EXPORT
     int			levelHeight (int ly) const;
 
 
@@ -249,7 +245,9 @@ class TiledInputFile
     //
     //--------------------------------------------------------------
 
+    IMF_EXPORT
     int			numXTiles (int lx = 0) const;
+    IMF_EXPORT
     int			numYTiles (int ly = 0) const;
 
 
@@ -272,8 +270,10 @@ class TiledInputFile
     //
     //---------------------------------------------------------------
 
-    Imath::Box2i	dataWindowForLevel (int l = 0) const;
-    Imath::Box2i	dataWindowForLevel (int lx, int ly) const;
+    IMF_EXPORT
+    IMATH_NAMESPACE::Box2i	dataWindowForLevel (int l = 0) const;
+    IMF_EXPORT
+    IMATH_NAMESPACE::Box2i	dataWindowForLevel (int lx, int ly) const;
 
 
     //-------------------------------------------------------------------
@@ -297,9 +297,11 @@ class TiledInputFile
     //
     //-------------------------------------------------------------------
 
-    Imath::Box2i	dataWindowForTile (int dx, int dy, int l = 0) const;
+    IMF_EXPORT
+    IMATH_NAMESPACE::Box2i	dataWindowForTile (int dx, int dy, int l = 0) const;
 
-    Imath::Box2i	dataWindowForTile (int dx, int dy,
+    IMF_EXPORT
+    IMATH_NAMESPACE::Box2i	dataWindowForTile (int dx, int dy,
                                            int lx, int ly) const;
 
     //------------------------------------------------------------
@@ -331,12 +333,16 @@ class TiledInputFile
     //
     //------------------------------------------------------------
 
+    IMF_EXPORT
     void		readTile  (int dx, int dy, int l = 0);
+    IMF_EXPORT
     void		readTile  (int dx, int dy, int lx, int ly);
 
+    IMF_EXPORT
     void		readTiles (int dx1, int dx2, int dy1, int dy2,
                                    int lx, int ly);
 
+    IMF_EXPORT
     void		readTiles (int dx1, int dx2, int dy1, int dy2,
                                    int l = 0);
 
@@ -345,37 +351,59 @@ class TiledInputFile
     // Read a tile of raw pixel data from the file,
     // without uncompressing it (this function is
     // used to implement TiledOutputFile::copyPixels()).
+    //
+    // for single part files, reads the next tile in the file
+    // for multipart files, reads the tile specified by dx,dy,lx,ly
+    //
     //--------------------------------------------------
 
+    IMF_EXPORT
     void		rawTileData (int &dx, int &dy,
 				     int &lx, int &ly,
 				     const char *&pixelData,
 				     int &pixelDataSize);
 
-    struct Data;
+    struct IMF_HIDDEN Data;
 
   private:
 
     friend class InputFile;
+    friend class MultiPartInputFile;
 
-    TiledInputFile (const TiledInputFile &);		  // not implemented
-    TiledInputFile & operator = (const TiledInputFile &); // not implemented
+    IMF_HIDDEN
+    TiledInputFile (InputPartData* part);
 
-    TiledInputFile (const Header &header, IStream *is, int version,
+    IMF_HIDDEN
+    TiledInputFile (const Header &header, OPENEXR_IMF_INTERNAL_NAMESPACE::IStream *is, int version,
                     int numThreads);
 
+    IMF_HIDDEN
     void		initialize ();
+    IMF_HIDDEN
+    void                multiPartInitialize(InputPartData* part);
+    IMF_HIDDEN
+    void                compatibilityInitialize(OPENEXR_IMF_INTERNAL_NAMESPACE::IStream& is);
 
+    IMF_HIDDEN
     bool		isValidTile (int dx, int dy,
 				     int lx, int ly) const;
 
+    IMF_HIDDEN
     size_t		bytesPerLineForTile (int dx, int dy,
 					     int lx, int ly) const;
 
+    IMF_HIDDEN
+    void                tileOrder(int dx[],int dy[],int lx[],int ly[]) const;
     Data *		_data;
+
+    friend class TiledOutputFile;
 };
 
 
-} // namespace Imf
+OPENEXR_IMF_INTERNAL_NAMESPACE_HEADER_EXIT
+
+
+
+
 
 #endif
